
class Payment(object):

    def __init__(self):

        self.account_id = None
        self.description = None
        self.additional_data = None # order (...), airline (...), seller_details (...)
        self.country = None
        self.merchant_order_id = None
        self.merchant_reference = None
        self.amount = None # currency, value
        self.customer_payer = None # customer ...
        self.checkout = None # session
        self.country = None
        self.workflow = None
        self.payment_method = None # token, vaulted_token, type, detail [card (...), ticket (...), wallet (...)]
        self.metadata = None # [key, value]
        self.callback_url = None
        self.fraud_screening = None #stand_alone



class Customer(object):

    def __init__(self):

        self.id = None
        self.merchant_customer_id = None
        self.merchant_customer_created_at = None
        self.first_name = None
        self.last_name = None
        self.gender = None
        self.date_of_birth = None
        self.email = None
        self.nationality = None
        self.country = None
        self.created_at = None
        self.updated_at = None
        self.document = None # document_number, document_type
        self.phone = None # country_code, number
        self.billing_address = None # address_line1, address_line2, city, country, state, zip_code, neighborhood
        self.shipping_address = None # address_line1, address_line2, city, country, state, zip_code, neighborhood
        self.metadata = None



import uuid
import requests
import json


class Yuno(object):

    api_version = "v1"

    def __init__(self, public_api_key, private_secret_key, sandbox):
        self.public_api_key = public_api_key
        self.private_secret_key = private_secret_key

        if not sandbox:
            self.api_base_url = "https://api.y.uno"
        else:
            self.api_base_url = "https://api-sandbox.y.uno"

    def headers(self):
        return {
            "Content-Type": "application/json",
            "charset": "utf-8",
            "Accept": "application/json",
            "private-secret-key": self.private_secret_key,
            "public-api-key": self.public_api_key,
            "X-idempotency-key": self.generate_idempotency_key(),
        }

    def base_request(self, url, method, data={}):
        base_url = self.api_base_url + "/" + self.api_version + "/"

        try:
            response = requests.request(
                method, base_url + url, data=json.dumps(data), headers=self.headers()
            )

            # return json.loads(response.content.decode("utf-8"))
            return response

        # TODO: Create especifics exceptions
        except Exception as error:
            raise

    def get(self, url, data={}):
        return self.base_request(url, "GET", data=data)

    def post(self, url, data={}):
        return self.base_request(url, "POST", data=data)

    def put(self, url, data={}):
        return self.base_request(url, "PUT", data=data)

    def generate_idempotency_key(self):
        return str(uuid.uuid4())



from setuptools import setup

with open("README.md", "r") as fh:
    readme = fh.read()

setup(name='yunoCTS',
    version='0.2',
    license='MIT License',
    author='SDK_PS',
    url='https://pypi.org/project/yunocts',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='payments@monetizze.com.br',
    keywords='yuno',
    description=u'SDK Yuno',
    packages=['yunoCTS'],)
